==> dec_unix-cpascal_V2.3A.tgz: cpascal/pcmp_envinh.c <==
/*  P A S - P. WOLFERS SOFTWARE: V2.1-E OF 31-AUG-2009 
  ***  PASCAL II implementation in C. *** */

/* Set specific Macro setting. */
#define CC_TYPE_SW short
#define CC_TYPE_SL   int
#define CC_TYPE_SQ long long int

/* Include the PAS environment file. */
#include "cpas_defs.h"

/* Define the local data section. */
static Blk( Rd, 120 ) = {
 13,  13, 105, 110, 104, 101, 114, 105, 116,  95, 114, 101,  99, 117, 114,  58,
 58,  47, 104, 111, 109, 101,  47, 112, 105, 101, 114, 114, 101,  47,  83, 111,
102, 116,  47,  99, 112, 115, 104,  95, 107, 105, 116, 115,  47,  99, 112,  97,
115,  99,  97, 108,  95,  86,  51,  95, 115, 114,  99,  47, 112,  99, 109, 112,
 95, 101, 110, 118, 105, 110, 104,  46, 112,  97, 115,  11,  11, 105, 110, 104,
101, 114, 105, 116,  95, 101, 110, 118,   4,   4,  46, 112,  97, 115,   4,   4,
 69,  78,  72,  69,  17,  17, 112,  97, 115,  95, 114, 101,  97, 100,  95, 101,
110, 118,  95, 102, 105, 108, 101,   0
};

/* Declaration of external variables. */
extern C V_sy_ch;
extern C V_sy_cmin;
extern V V_src_control;
extern Blk(V_sy_sym, 8 );
extern Blk(V_sy_string, 264 );
extern V V_atts_list;
extern Blk(V_sy_ident, 32 );
extern UB V_error_result;
extern UB V_emergency_stop;
extern UB V_lastsymb;
extern SL V_sy_ival;
extern G V_sy_rval;
extern V V_env_first;


/* Function/procedure prototypes. */
void P_src_close(V *F_p, UB F_bfree);
void P_src_open(V *F_p, V F_fspc, UB F_bdelete, SL *F_ierr);
void P_src_error(V F_modnam, SL F_number, UB F_severity);
void P_src_error_s(V F_modulesy, SL F_number, UB F_severity, V F_id1, V F_id2);
V P_level_search(V F_fp);
void P_set_env_file_spc(V F_pcur);
void P_compile_set_title();
void P_set_srcfilespc(SL F_icd);
void P_insymbol();
void PAS_ENV_INH_inherit_env(V F_env);


/* Procedure/Function : " env_block "  */
void PAS_ENV_INH_env_block(){

  /* Code of procedure/function */
}


/* Procedure/Function : " inherit_recur "  */
void PAS_ENV_INH_inherit_recur(V F_env){
  /* Define the automatic variable space. */
  Blk( Ra, 32 );

  /* Local variable stored in C variable */
  C Rv0;
  C Rv1;

  /* Code of procedure/function */
  Ra.v[0]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s;
  Ra.v[1]=Rd.s;
  Ra.v[2]=Rd.s+15;
  Ra.sl[6]=113; /* line # 113 */
  P_set_env_file_spc(F_env);
  Rv0=V_sy_ch;
  Rv1=V_sy_cmin;
  PAS_ENV_INH_inherit_env(F_env);
  V_sy_ch=Rv0;
  Ra.sl[6]=118; /* line # 118 */
  V_sy_cmin=Rv1;
  PAS__curr_cntx=Ra.v[0];
}


/* Procedure/Function : " inherit_env "  */
void PAS_ENV_INH_inherit_env(V F_env){
  /* Define the automatic variable space. */
  Blk( Ra, 552 );

  /* Local variable stored in C variable */
  UB Rv0;
  V Rv1;
  V Rv2;
  V Rv3;
  V Rv4;
  register V Rv5;
  SL Rv6;
  SL Rv7;
  register V Rv8;
  V Rv9;

  /* Code of procedure/function */
  Ra.ub[0]=255;
  Ra.v[33]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s+264;
  Ra.v[34]=Rd.s+75;
  Ra.v[35]=Rd.s+15;
  Ra.sl[72]=136; /* line # 136 */
  Rv0=0;
  Rv1=NULL;
  Rv2=NULL;
  Rv3=V_src_control;
  Rv4=NULL;
  Ra.sl[72]=141; /* line # 141 */
  Rv5=F_env;
  PAS__STR_TO_STR(Ra.s,((V *)Rv5)[1]);
  Rv6=PAS__NINDEX_CHA(Ra.s+2,(SL)Ra.ub[1],46,-1,-1,1);
  if (Rv6!=0) {
    Ra.sl[72]=146; /* line # 146 */
    if (Ra.c[Rv6+1]==46) PAS__STR_TO_STR(Ra.s,PAS__CON_STR_STR(Ra.s+292,Ra.s,Rd.
    s+88));
  }
  P_src_open(&Rv4, Ra.s,0, &Rv7);
  if (Rv7==0) {
    Ra.sl[72]=152; /* line # 152 */
    Rv8=Rv4;
    ((V *)Rv8)[1]=V_src_control;
    ((SL *)Rv8)[7]=((SL *)V_src_control)[7]+1;
    ((SL *)Rv8)[8]=((SL *)V_src_control)[8];
    Ra.sl[72]=157; /* line # 157 */
    ((SL *)Rv8)[6]=((SL *)V_src_control)[6];
    ((UL *)Rv8)[62]=((UL *)Rv8)[62]&102;
    P_compile_set_title();
    Ra.sl[72]=162; /* line # 162 */
    P_set_srcfilespc(1);
    V_sy_ch=32;
    V_sy_sym.ub[0]=97;
    V_src_control=Rv4;
    P_insymbol();
    Ra.sl[72]=168; /* line # 168 */
    if (V_sy_sym.ub[0]==72) {
      V_sy_sym.ub[0]=18;
      while (1){
        Ra.sl[72]=174; /* line # 174 */
        P_insymbol();
        if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) PAS_ENV_INH_inherit_recur(F_env);
        else P_src_error(Rd.s+96,58,3);
        Ra.sl[72]=179; /* line # 179 */
        P_insymbol();
        if (V_sy_sym.ub[0]!=18)  break;
      }
      if (V_sy_sym.ub[0]==19) P_insymbol();
      else P_src_error(Rd.s+96,21,2);
    }
    else {
      Ra.sl[72]=184; /* line # 184 */
      if (V_sy_sym.ub[0]==16) {
        V_sy_sym.ub[0]=18;
        while (1){
          Ra.sl[72]=189; /* line # 189 */
          P_insymbol();
          if (V_sy_sym.ub[0]==0) {
            Rv9=P_level_search(V_atts_list);
            if (Rv9!=NULL) while (1){
              Ra.sl[72]=195; /* line # 195 */
              P_insymbol();
              switch (((UB *)Rv9)[57]) {
                case 18:if (V_sy_sym.ub[0]!=14) P_src_error(Rd.s+96,22,2);
                Ra.sl[72]=200; /* line # 200 */
                V_sy_sym.ub[0]=18;
                while (1){
                  P_insymbol();
                  if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) PAS_ENV_INH_inherit_recur(
                  F_env);
                  else {
                    Ra.sl[72]=206; /* line # 206 */
                    P_src_error(Rd.s+96,58,3);
                  }
                  P_insymbol();
                  if (V_sy_sym.ub[0]!=18)  break;
                }
                if (V_sy_sym.ub[0]==15) P_insymbol();
                else P_src_error(Rd.s+96,23,2);
                break;
                case 19:Ra.sl[72]=215; /* line # 215 */
                if (V_sy_sym.ub[0]==14) P_insymbol();
                else P_src_error(Rd.s+96,22,2);
                if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) {
                  Rv0=1;
                  Ra.sl[72]=220; /* line # 220 */
                  P_insymbol();
                }
                if (V_sy_sym.ub[0]==15) P_insymbol();
                else P_src_error(Rd.s+96,23,2);
                break;
                default:Ra.sl[72]=226; /* line # 226 */
                P_src_error_s(Rd.s+96,3,1, V_sy_ident.s,NULL);
                break;
              }
              if ((V_sy_sym.ub[0]==87||V_sy_sym.ub[0]==18)||V_sy_sym.ub[0]==17)  break;
            }
          }
          else P_src_error(Rd.s+96,2,3);
          if (V_sy_sym.ub[0]!=18)  break;
        }
        Ra.sl[72]=232; /* line # 232 */
        if (V_sy_sym.ub[0]==17) P_insymbol();
        else P_src_error(Rd.s+96,26,2);
      }
    }
    if (V_sy_sym.ub[0]==73) {
      Ra.sl[72]=238; /* line # 238 */
      P_insymbol();
      if (V_sy_sym.ub[0]!=0) P_src_error(Rd.s+96,93,4);
    }
    else P_src_error(Rd.s+96,999,4);
    Ra.sl[72]=244; /* line # 244 */
    if (V_error_result>1) V_emergency_stop=1;
    if (!V_emergency_stop) PAS_ENV_INH_env_block();
    if (V_src_control!=Rv4) {
      Ra.sl[72]=250; /* line # 250 */
      P_src_error(Rd.s+96,5,4);
      V_emergency_stop=1;
    }
    else {
      Ra.sl[72]=255; /* line # 255 */
      V_src_control=Rv3;
      P_src_close(&Rv4,1);
      P_set_srcfilespc(-1);
      if (V_error_result>1) V_emergency_stop=1;
    }
  }
  else {
    Ra.sl[72]=262; /* line # 262 */
    P_src_error(Rd.s+96,4,4);
  }
  PAS__curr_cntx=Ra.v[33];
}


/* Procedure/Function : " pas_read_env_file "  */
void P_pas_read_env_file(){
  /* Define the automatic variable space. */
  Blk( Ra, 296 );

  /* Local variable stored in C variable */
  C Rv0;
  C Rv1;
  UB Rv2;
  SL Rv3;
  G Rv4;
  V Rv5;

  /* Code of procedure/function */
  Ra.ub[0]=255;
  Ra.v[33]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s+264;
  Ra.v[34]=Rd.s+100;
  Ra.v[35]=Rd.s+15;
  Ra.sl[72]=280; /* line # 280 */
  Rv0=V_sy_ch;
  Rv1=V_sy_cmin;
  Rv2=V_lastsymb;
  memcpy(Ra.s+292,V_sy_sym.s,2);
  PAS__STR_TO_STR(Ra.s,V_sy_string.s);
  Ra.sl[72]=285; /* line # 285 */
  Rv3=V_sy_ival;
  Rv4=V_sy_rval;
  Rv5=V_env_first;
  Ra.sl[72]=290; /* line # 290 */
  while (Rv5!=NULL){
    PAS_ENV_INH_inherit_env(Rv5);
    Rv5=((V *)Rv5)[0];
  }
  Ra.sl[72]=298; /* line # 298 */
  V_sy_ch=Rv0;
  V_sy_cmin=Rv1;
  V_lastsymb=Rv2;
  memcpy(V_sy_sym.s,Ra.s+292,2);
  V_sy_ival=Rv3;
  Ra.sl[72]=303; /* line # 303 */
  V_sy_rval=Rv4;
  PAS__curr_cntx=Ra.v[33];
}


/* Procedure/Function : " pas_write_env_file "  */
void P_pas_write_env_file(){

  /* Code of procedure/function */
}

==> dec_unix-cpascal_V3.1A.tgz: cpascal/pcmp_envinh.c <==
/*  P A S - P. WOLFERS SOFTWARE: V3.0-A OF 31-OCT-2014 
  ***  PASCAL II implementation in C. *** */

/* Set specific Macro setting. */
#define CC_TYPE_SW short
#define CC_TYPE_SL   int
#define CC_TYPE_SQ long long int

/* Include the PAS environment file. */
#include "cpas_defs.h"

/* Define the local data section. */
static Blk( Rd, 128 ) = {
 13,  13, 105, 110, 104, 101, 114, 105, 116,  95, 114, 101,  99, 117, 114,  60,
 60,  47, 104, 111, 109, 101,  47, 112, 105, 101, 114, 114, 101,  47,  83, 111,
102, 116,  47,  99, 112, 115, 104,  95, 107, 105, 116, 115,  47,  99, 112,  97,
115,  99,  97, 108,  95,  86,  51,  95,  65,  95, 115, 114,  99,  47, 112,  99,
109, 112,  95, 101, 110, 118, 105, 110, 104,  46, 112,  97, 115,  11,  11, 105,
110, 104, 101, 114, 105, 116,  95, 101, 110, 118,   4,   4,  46, 112,  97, 115,
  4,   4,  69,  78,  72,  69,  17,  17, 112,  97, 115,  95, 114, 101,  97, 100,
 95, 101, 110, 118,  95, 102, 105, 108, 101,   0,   0,   0,   0,   0,   0,   0
};

/* Declaration of external variables. */
extern C V_sy_ch;
extern C V_sy_cmin;
extern V V_src_control;
extern Blk(V_sy_sym, 8 );
extern Blk(V_sy_string, 264 );
extern V V_atts_list;
extern Blk(V_sy_ident, 32 );
extern UB V_error_result;
extern UB V_emergency_stop;
extern UB V_lastsymb;
extern SL V_sy_ival;
extern G V_sy_rval;
extern V V_env_first;


/* Function/procedure prototypes. */
void P_src_close(V *F_p, UB F_bfree);
void P_src_open(V *F_p, V F_fspc, UB F_bdelete, SL *F_ierr);
void P_src_error(V F_modnam, SL F_number, UB F_severity);
void P_src_error_s(V F_modulesy, SL F_number, UB F_severity, V F_id1, V F_id2);
V P_level_search(V F_fp);
void P_set_env_file_spc(V F_pcur);
void P_compile_set_title();
void P_set_srcfilespc(SL F_icd);
void P_insymbol();
void PAS_ENV_INH_inherit_env(V F_env);


/* Procedure/Function : " env_block "  */
void PAS_ENV_INH_env_block(){

  /* Code of procedure/function */
}


/* Procedure/Function : " inherit_recur "  */
void PAS_ENV_INH_inherit_recur(V F_env){
  /* Define the automatic variable space. */
  Blk( Ra, 32 );

  /* Local variable stored in C variable */
  C Rv0;
  C Rv1;

  /* Code of procedure/function */
  Ra.v[0]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s;
  Ra.v[1]=Rd.s;
  Ra.v[2]=Rd.s+15;
  Ra.sl[6]=113; /* line # 113 */
  P_set_env_file_spc(F_env);
  Rv0=V_sy_ch;
  Rv1=V_sy_cmin;
  PAS_ENV_INH_inherit_env(F_env);
  V_sy_ch=Rv0;
  Ra.sl[6]=118; /* line # 118 */
  V_sy_cmin=Rv1;
  PAS__curr_cntx=Ra.v[0];
}


/* Procedure/Function : " inherit_env "  */
void PAS_ENV_INH_inherit_env(V F_env){
  /* Define the automatic variable space. */
  Blk( Ra, 552 );

  /* Local variable stored in C variable */
  UB Rv0;
  V Rv1;
  V Rv2;
  V Rv3;
  V Rv4;
  register V Rv5;
  SL Rv6;
  SL Rv7;
  register V Rv8;
  V Rv9;

  /* Code of procedure/function */
  Ra.ub[0]=255;
  Ra.v[33]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s+264;
  Ra.v[34]=Rd.s+77;
  Ra.v[35]=Rd.s+15;
  Ra.sl[72]=136; /* line # 136 */
  Rv0=0;
  Rv1=NULL;
  Rv2=NULL;
  Rv3=V_src_control;
  Rv4=NULL;
  Ra.sl[72]=141; /* line # 141 */
  Rv5=F_env;
  PAS__STR_TO_STR(Ra.s,((V *)Rv5)[1]);
  Rv6=PAS__NINDEX_CHA(Ra.s+2,(SL)Ra.ub[1],46,-1,-1,1);
  if (Rv6!=0) {
    Ra.sl[72]=146; /* line # 146 */
    if (Ra.c[Rv6+1]==46) PAS__STR_TO_STR(Ra.s,PAS__CON_STR_STR(Ra.s+292,Ra.s,Rd.
    s+90));
  }
  P_src_open(&Rv4, Ra.s,0, &Rv7);
  if (Rv7==0) {
    Ra.sl[72]=152; /* line # 152 */
    Rv8=Rv4;
    ((V *)Rv8)[1]=V_src_control;
    ((SL *)Rv8)[7]=((SL *)V_src_control)[7]+1;
    ((SL *)Rv8)[8]=((SL *)V_src_control)[8];
    Ra.sl[72]=157; /* line # 157 */
    ((SL *)Rv8)[6]=((SL *)V_src_control)[6];
    ((UL *)Rv8)[62]=((UL *)Rv8)[62]&102;
    P_compile_set_title();
    Ra.sl[72]=162; /* line # 162 */
    P_set_srcfilespc(1);
    V_sy_ch=32;
    V_sy_sym.ub[0]=99;
    V_src_control=Rv4;
    P_insymbol();
    Ra.sl[72]=168; /* line # 168 */
    if (V_sy_sym.ub[0]==74) {
      V_sy_sym.ub[0]=18;
      while (1){
        Ra.sl[72]=174; /* line # 174 */
        P_insymbol();
        if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) PAS_ENV_INH_inherit_recur(F_env);
        else P_src_error(Rd.s+98,58,3);
        Ra.sl[72]=179; /* line # 179 */
        P_insymbol();
        if (V_sy_sym.ub[0]!=18)  break;
      }
      if (V_sy_sym.ub[0]==19) P_insymbol();
      else P_src_error(Rd.s+98,21,2);
    }
    else {
      Ra.sl[72]=184; /* line # 184 */
      if (V_sy_sym.ub[0]==16) {
        V_sy_sym.ub[0]=18;
        while (1){
          Ra.sl[72]=189; /* line # 189 */
          P_insymbol();
          if (V_sy_sym.ub[0]==0) {
            Rv9=P_level_search(V_atts_list);
            if (Rv9!=NULL) while (1){
              Ra.sl[72]=195; /* line # 195 */
              P_insymbol();
              switch (((UB *)Rv9)[57]) {
                case 18:if (V_sy_sym.ub[0]!=14) P_src_error(Rd.s+98,22,2);
                Ra.sl[72]=200; /* line # 200 */
                V_sy_sym.ub[0]=18;
                while (1){
                  P_insymbol();
                  if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) PAS_ENV_INH_inherit_recur(
                  F_env);
                  else {
                    Ra.sl[72]=206; /* line # 206 */
                    P_src_error(Rd.s+98,58,3);
                  }
                  P_insymbol();
                  if (V_sy_sym.ub[0]!=18)  break;
                }
                if (V_sy_sym.ub[0]==15) P_insymbol();
                else P_src_error(Rd.s+98,23,2);
                break;
                case 19:Ra.sl[72]=215; /* line # 215 */
                if (V_sy_sym.ub[0]==14) P_insymbol();
                else P_src_error(Rd.s+98,22,2);
                if (V_sy_sym.ub[0]==5&&V_sy_string.ub[1]>0) {
                  Rv0=1;
                  Ra.sl[72]=220; /* line # 220 */
                  P_insymbol();
                }
                if (V_sy_sym.ub[0]==15) P_insymbol();
                else P_src_error(Rd.s+98,23,2);
                break;
                default:Ra.sl[72]=226; /* line # 226 */
                P_src_error_s(Rd.s+98,3,1, V_sy_ident.s,NULL);
                break;
              }
              if ((V_sy_sym.ub[0]==89||V_sy_sym.ub[0]==18)||V_sy_sym.ub[0]==17)  break;
            }
          }
          else P_src_error(Rd.s+98,2,3);
          if (V_sy_sym.ub[0]!=18)  break;
        }
        Ra.sl[72]=232; /* line # 232 */
        if (V_sy_sym.ub[0]==17) P_insymbol();
        else P_src_error(Rd.s+98,26,2);
      }
    }
    if (V_sy_sym.ub[0]==75) {
      Ra.sl[72]=238; /* line # 238 */
      P_insymbol();
      if (V_sy_sym.ub[0]!=0) P_src_error(Rd.s+98,93,4);
    }
    else P_src_error(Rd.s+98,999,4);
    Ra.sl[72]=244; /* line # 244 */
    if (V_error_result>1) V_emergency_stop=1;
    if (!V_emergency_stop) PAS_ENV_INH_env_block();
    if (V_src_control!=Rv4) {
      Ra.sl[72]=250; /* line # 250 */
      P_src_error(Rd.s+98,5,4);
      V_emergency_stop=1;
    }
    else {
      Ra.sl[72]=255; /* line # 255 */
      V_src_control=Rv3;
      P_src_close(&Rv4,1);
      P_set_srcfilespc(-1);
      if (V_error_result>1) V_emergency_stop=1;
    }
  }
  else {
    Ra.sl[72]=262; /* line # 262 */
    P_src_error(Rd.s+98,4,4);
  }
  PAS__curr_cntx=Ra.v[33];
}


/* Procedure/Function : " pas_read_env_file "  */
void P_pas_read_env_file(){
  /* Define the automatic variable space. */
  Blk( Ra, 296 );

  /* Local variable stored in C variable */
  C Rv0;
  C Rv1;
  UB Rv2;
  SL Rv3;
  G Rv4;
  V Rv5;

  /* Code of procedure/function */
  Ra.ub[0]=255;
  Ra.v[33]=PAS__curr_cntx;
  PAS__curr_cntx=Ra.s+264;
  Ra.v[34]=Rd.s+102;
  Ra.v[35]=Rd.s+15;
  Ra.sl[72]=280; /* line # 280 */
  Rv0=V_sy_ch;
  Rv1=V_sy_cmin;
  Rv2=V_lastsymb;
  memcpy(Ra.s+292,V_sy_sym.s,2);
  PAS__STR_TO_STR(Ra.s,V_sy_string.s);
  Ra.sl[72]=285; /* line # 285 */
  Rv3=V_sy_ival;
  Rv4=V_sy_rval;
  Rv5=V_env_first;
  Ra.sl[72]=290; /* line # 290 */
  while (Rv5!=NULL){
    PAS_ENV_INH_inherit_env(Rv5);
    Rv5=((V *)Rv5)[0];
  }
  Ra.sl[72]=298; /* line # 298 */
  V_sy_ch=Rv0;
  V_sy_cmin=Rv1;
  V_lastsymb=Rv2;
  memcpy(V_sy_sym.s,Ra.s+292,2);
  V_sy_ival=Rv3;
  Ra.sl[72]=303; /* line # 303 */
  V_sy_rval=Rv4;
  PAS__curr_cntx=Ra.v[33];
}


/* Procedure/Function : " pas_write_env_file "  */
void P_pas_write_env_file(){

  /* Code of procedure/function */
}
